@@ -178,14 +178,14 @@ test_that("works similar way as before v0.9", {
                             sifi = c("alien*", "star", "space")))
 
     set.seed(1234)
-    lda <- textmodel_seededlda(dfmt, dict, residual = TRUE, weight = 0.1, uniform = TRUE,
+    lda <- textmodel_seededlda(dfmt, dict, residual = TRUE, weight = 0.1,
                                max_iter = 2000)
     set.seed(1234)
     lda_old <- textmodel_seededlda(dfmt, dict, residual = TRUE, weight = 0.01, old = TRUE,
                                    max_iter = 2000)
 
     tb <- table(topics(lda), topics(lda_old))
-    expect_true(all(diag(tb) / rowSums(tb) > 0.85))
+    expect_true(all(diag(tb) / rowSums(tb) > 0.80))
 })
 
 
@@ -268,4 +268,37 @@ test_that("auto_iter works", {
 })
 
 
+test_that("levels is working", {
+
+	lis <- list(romance = c("love*", "couple*"),
+				sifi = list(space = c("star", "space"),
+							monster = c("alien*", "monster")))
+	dict <- dictionary(lis)
+
+	lda1 <- textmodel_seededlda(dfmt, dict, levels = 1, residual = TRUE,
+								min_termfreq = 10, max_iter = 100)
+	expect_equal(
+		levels(topics(lda1)),
+		c("romance", "sifi", "other")
+	)
+	lda2 <- textmodel_seededlda(dfmt, dict, levels = 1:2, residual = TRUE,
+								min_termfreq = 10, max_iter = 100)
+	expect_equal(
+		levels(topics(lda2)),
+		c("romance", "sifi.space", "sifi.monster", "other")
+	)
+	lda3 <- textmodel_seededlda(dfmt, dict, levels = 2, residual = TRUE,
+								min_termfreq = 10, max_iter = 100)
+	expect_equal(
+		levels(topics(lda3)),
+		c("space", "monster", "other")
+	)
+
+	expect_error(
+		textmodel_seededlda(dfmt, dict, levels = -1, residual = TRUE,
+							min_termfreq = 10, max_iter = 100),
+		"The value of levels must be between 1 and Inf"
+	)
+
+})
 
